'use client'

import { useState, useRef, useEffect } from 'react'
import { FiSave, FiImage, FiX } from 'react-icons/fi'
import DashboardLayout from '../../../../components/layout/DashboardLayout'
import { categoryService, productService } from '@/services/api'
import { useUser } from '@/contexts/UserContext'
import { useRouter } from 'next/navigation'
import Modal from '@/components/ui/Modal'

export default function AddProductPage() {
  const { user } = useUser()
  const router = useRouter()
  const [formData, setFormData] = useState({
    name: '',
    price: '',
    category_id: '',
    image: '',
    description: '',
    kitchen_print: false
  })
  const [image, setImage] = useState<string | null>(null)
  const fileInputRef = useRef<HTMLInputElement>(null)
  const [categories, setCategories] = useState([])
  const [error, setError] = useState(false)
  const [success, setSuccess] = useState(false)


  const handleInputChange = (e: React.ChangeEvent<HTMLInputElement | HTMLTextAreaElement | HTMLSelectElement>) => {
    const { name, value } = e.target
    setFormData(prev => ({
      ...prev,
      [name]: value
    }))
  }

  const handleImageChange = (e: React.ChangeEvent<HTMLInputElement>) => {
    const file = e.target.files?.[0]
    if (file) {
      const reader = new FileReader()
      reader.onloadend = () => {
        const base64String = reader.result as string
        setImage(base64String)
        setFormData(prev => ({
          ...prev,
          image: base64String
        }))
      }
      reader.readAsDataURL(file)
    }
  }

  const removeImage = () => {
    setImage(null)
    setFormData(prev => ({
      ...prev,
      image: ''
    }))
    if (fileInputRef.current) {
      fileInputRef.current.value = ''
    }
  }

  const handleSubmit = async (e: React.FormEvent) => {
    e.preventDefault()
    try {
      const formDataToSend = new FormData()
      formDataToSend.append('category_id', formData.category_id)
      formDataToSend.append('name', formData.name)
      formDataToSend.append('price', formData.price)
      formDataToSend.append('description', formData.description)
      formDataToSend.append('kitchen_print', formData.kitchen_print ? '1' : '0')

      // Eğer dosya seçilmişse ekle
      const file = fileInputRef.current?.files?.[0]
      if (file) {
        formDataToSend.append('image', file, file.name)
      }

      await productService.store(formDataToSend, user?.token || '')
      setSuccess(true)
      setTimeout(() => {
        router.push('/dashboard/products')
      }, 1500)
    } catch (err) {
      setError(true)
    }
  }

  const fetchCategories = async () => {
    try {
      const response = await categoryService.index(user?.token || '')
      setCategories(response.data.categories)
    } catch (err) {
      setError(true)
    }
  }

  useEffect(() => {
    if (user?.token) {
      fetchCategories()
    }
  }, [user?.token])
  
  return (
    <DashboardLayout>
      <div className="w-full mx-auto">
        <div className="bg-white/50 dark:bg-slate-800/50 backdrop-blur-sm rounded-3xl shadow-lg 
                     border border-slate-200/50 dark:border-slate-700/50">
          <div className="p-6 border-b border-slate-200/50 dark:border-slate-700/50">
            <h2 className="text-xl font-bold text-slate-800 dark:text-white">
              Yeni Ürün Ekle
            </h2>
            <p className="text-sm text-slate-500 dark:text-slate-400 mt-1">
              Yeni bir ürün eklemek için aşağıdaki formu doldurun
            </p>
          </div>

          <form onSubmit={handleSubmit} className="p-6 space-y-6">
            <div className="grid grid-cols-1 md:grid-cols-2 gap-6">
              {/* Ürün Adı */}
              <div>
                <label htmlFor="name" className="block text-sm font-medium text-slate-700 dark:text-slate-300 mb-2">
                  Ürün Adı
                </label>
                <input
                  id="name"
                  name="name"
                  type="text"
                  value={formData.name}
                  onChange={handleInputChange}
                  className="w-full px-4 py-2.5 rounded-xl border border-slate-200/50 dark:border-slate-700/50 
                           bg-white/50 dark:bg-slate-700/50 backdrop-blur-sm
                           text-slate-800 dark:text-white
                           focus:outline-none focus:ring-2 focus:ring-fuchsia-500/50
                           transition-all placeholder-slate-400 dark:placeholder-slate-500"
                  placeholder="Örn: Türk Kahvesi"
                  required
                />
              </div>

              {/* Fiyat */}
              <div>
                <label htmlFor="price" className="block text-sm font-medium text-slate-700 dark:text-slate-300 mb-2">
                  Fiyat
                </label>
                <div className="relative">
                  <span className="absolute left-4 top-1/2 -translate-y-1/2 text-slate-400">₺</span>
                  <input
                    id="price"
                    name="price"
                    type="number"
                    step="0.01"
                    min="0"
                    value={formData.price}
                    onChange={handleInputChange}
                    className="w-full pl-8 pr-4 py-2.5 rounded-xl border border-slate-200/50 dark:border-slate-700/50 
                             bg-white/50 dark:bg-slate-700/50 backdrop-blur-sm
                             text-slate-800 dark:text-white
                             focus:outline-none focus:ring-2 focus:ring-fuchsia-500/50
                             transition-all placeholder-slate-400 dark:placeholder-slate-500"
                    placeholder="0"
                    required
                  />
                </div>
              </div>

              {/* Kategori */}
              <div>
                <label htmlFor="categoryId" className="block text-sm font-medium text-slate-700 dark:text-slate-300 mb-2">
                  Kategori
                </label>
                <select
                  id="categoryId"
                  name="category_id"
                  value={formData.category_id}
                  onChange={handleInputChange}
                  className="w-full px-4 py-2.5 rounded-xl border border-slate-200/50 dark:border-slate-700/50 
                           bg-white/50 dark:bg-slate-700/50 backdrop-blur-sm
                           text-slate-800 dark:text-white
                           focus:outline-none focus:ring-2 focus:ring-fuchsia-500/50
                           transition-all"
                  required
                >
                  <option value="">Kategori Seçin</option>
                  {categories.map((category: any) => (
                    <option key={category.id} value={category.id}>
                      {category.name}
                    </option>
                  ))}
                </select>
              </div>

              {/* Resim Yükleme */}
              <div>
                <label className="block text-sm font-medium text-slate-700 dark:text-slate-300 mb-2">
                  Ürün Görseli
                </label>
                <div className="relative">
                  <input
                    type="file"
                    name="image"
                    ref={fileInputRef}
                    onChange={handleImageChange}
                    accept="image/*"
                    className="hidden"
                  />
                  {image ? (
                    <div className="relative w-full aspect-video rounded-xl overflow-hidden">
                      <img
                        src={image}
                        alt="Ürün görseli"
                        className="w-full h-full object-cover"
                      />
                      <button
                        type="button"
                        onClick={removeImage}
                        className="absolute top-2 right-2 p-1.5 rounded-lg bg-red-500/80 text-white 
                                 hover:bg-red-500 transition-colors"
                      >
                        <FiX className="w-4 h-4" />
                      </button>
                    </div>
                  ) : (
                    <button
                      type="button"
                      onClick={() => fileInputRef.current?.click()}
                      className="w-full px-4 py-4 rounded-xl border-2 border-dashed 
                               border-slate-200/50 dark:border-slate-700/50
                               hover:border-fuchsia-500/50 dark:hover:border-fuchsia-500/50
                               transition-colors flex flex-col items-center gap-2"
                    >
                      <FiImage className="w-6 h-6 text-slate-400" />
                      <span className="text-sm text-slate-500 dark:text-slate-400">
                        Görsel yüklemek için tıklayın
                      </span>
                    </button>
                  )}
                </div>
              </div>
            </div>

            {/* Mutfak Yazdırma Seçeneği */}
            <div className="col-span-full">
              <div className="flex items-center gap-2">
                <input
                  type="checkbox"
                  id="kitchen_print"
                  name="kitchen_print"
                  checked={formData.kitchen_print}
                  onChange={(e) => setFormData(prev => ({
                    ...prev,
                    kitchen_print: e.target.checked
                  }))}
                  className="w-4 h-4 text-fuchsia-500 border-slate-300 dark:border-slate-600 
                           rounded focus:ring-fuchsia-500/50"
                />
                <label 
                  htmlFor="kitchen_print" 
                  className="text-sm font-medium text-slate-700 dark:text-slate-300"
                >
                  Mutfağa Gönder
                </label>
                <span className="text-xs text-slate-500 dark:text-slate-400">
                  (Bu ürün mutfak yazıcısına gönderilecek)
                </span>
              </div>
            </div>

            {/* İçindekiler */}
            <div>
              <label htmlFor="description" className="block text-sm font-medium text-slate-700 dark:text-slate-300 mb-2">
                İçindekiler
              </label>
              <textarea
                id="description"
                name="description"
                value={formData.description}
                onChange={handleInputChange}
                rows={4}
                className="w-full px-4 py-2.5 rounded-xl border border-slate-200/50 dark:border-slate-700/50 
                         bg-white/50 dark:bg-slate-700/50 backdrop-blur-sm
                         text-slate-800 dark:text-white
                         focus:outline-none focus:ring-2 focus:ring-fuchsia-500/50
                         transition-all placeholder-slate-400 dark:placeholder-slate-500"
                placeholder="Ürün içeriklerini buraya yazın..."
              />
            </div>

            {/* Kaydet Butonu */}
            <div className="flex justify-end">
              <button
                type="submit"
                className="px-6 py-2.5 text-sm font-medium text-white 
                         bg-gradient-to-r from-fuchsia-500 to-purple-600 
                         rounded-xl hover:opacity-90 transition-all 
                         shadow-lg shadow-fuchsia-500/25
                         flex items-center gap-2"
              >
                <FiSave className="w-4 h-4" />
                <span>Kaydet</span>
              </button>
            </div>
          </form>
        </div>
      </div>
      <Modal
        isOpen={success}
        onClose={() => setSuccess(false)}
        title="Başarılı"
        message="Ürün başarıyla eklendi yönlendiriliyorsunuz..."
      />
      <Modal
        isOpen={error}
        onClose={() => setError(false)}
        title="Hata"
        message="Ürün eklenirken bir hata oluştu"
      />
    </DashboardLayout>
  )
} 